@@ -1,7 +1,7 @@
 package Screensaver::Any;
 
-our $DATE = '2017-03-30'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2017-03-31'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -69,6 +69,7 @@ sub detect_screensaver {
     }
 
     require Proc::Find;
+    no warnings 'once';
     local $Proc::Find::CACHE = 1;
 
   GNOME:
@@ -171,7 +172,7 @@ sub _get_or_set_screensaver_timeout {
 
 $SPEC{get_screensaver_timeout} = {
     v => 1.1,
-    summary => 'Get screensaver timeout, in number of seconds',
+    summary => 'Get screensaver idle timeout, in number of seconds',
     args => {
         %arg_screensaver,
     },
@@ -186,7 +187,7 @@ sub get_screensaver_timeout {
 
 $SPEC{set_screensaver_timeout} = {
     v => 1.1,
-    summary => 'Set screensaver timeout',
+    summary => 'Set screensaver idle timeout',
     description => <<'_',
 
 * xscreensaver
@@ -325,8 +326,13 @@ $SPEC{deactivate_screensaver} = {
     description => <<'_',
 
 If screen is not being blank (screensaver is not activated) then nothing
-happens. Also, if screen is being locked, it will not be unlocked. User will
-need to unlock the screen herself first.
+happens. If screen is being blanked (screensaver is activated) then unblank the
+screen.
+
+Often the screen is also locked when being blanked. On some screensavers, like
+xscreensaver, deactivating won't unlock the screen and user will need to unlock
+the screen herself first. Some other screensavers, like GNOME/cinnamon, will
+happily unlock the screen automatically.
 
 _
     args => {
@@ -338,7 +344,7 @@ sub deactivate_screensaver {
     my $screensaver = $args{screensaver} // detect_screensaver();
 
     if ($screensaver eq 'kde') {
-        return [501, "This function is not supported by kde"];
+        return [501, "Deactivating screensaver is not supported on kde"];
     }
 
     if ($screensaver eq 'gnome') {
@@ -352,22 +358,24 @@ sub deactivate_screensaver {
     }
 
     if ($screensaver eq 'xscreensaver') {
-        system "xscreensaver-command", "-deactivate";
+        system({capture_stdout=>\my $dummy_stdout},
+               "xscreensaver-command", "-deactivate");
         if ($?) { return [500, "Failed"] } else { return [200, "OK"] }
     }
 
     [412, "Unknown screensaver '$screensaver'"];
 }
 
-$SPEC{is_screensaver_active} = {
+$SPEC{screensaver_is_active} = {
     v => 1.1,
     summary => 'Check if screensaver is being activated',
     args => {
         %arg_screensaver,
     },
 };
-sub is_screensaver_active {
+sub screensaver_is_active {
     my %args = @_;
+
     my $screensaver = $args{screensaver} // detect_screensaver();
 
     if ($screensaver eq 'kde') {
@@ -410,10 +418,53 @@ sub is_screensaver_active {
     [412, "Unknown screensaver '$screensaver'"];
 }
 
+$SPEC{prevent_screensaver_activated} = {
+    v => 1.1,
+    summary => 'Prevent screensaver from being activated by resetting idle timer',
+    description => <<'_',
+
+You can use this function to prevent screensaver from being activated, if it is
+not yet being activated. This is usually done by resetting the idle counter.
+With KDE, this is called "simulating user activity". With xscreensaver, one can
+use the -deactivate on the CLI.
+
+This function will need to be run periodically and often enough (more often than
+the idle timeout period) to actually keep the screensaver from ever being
+activated.
+
+If screensaver is already activated, then nothing happens.
+
+_
+};
+sub prevent_screensaver_activated {
+    my %args = @_;
+
+    my $screensaver = $args{screensaver} // detect_screensaver();
+
+    if ($screensaver eq 'kde') {
+        system "qdbus", "org.kde.screensaver", "/ScreenSaver", "SimulateUserActivity";
+        return $? ? [500, "Failed"] : [200];
+    }
+
+    if ($screensaver eq 'gnome') {
+        return [501, "Preventing screensaver from being activated not yet supported on gnome"];
+    }
+
+    if ($screensaver eq 'cinnamon') {
+        return [501, "Preventing screensaver from being activated not yet supported on cinnamon"];
+    }
+
+    if ($screensaver eq 'xscreensaver') {
+        system({capture_stdout => \my $dummy_stdout},
+               "xscreensaver-command", "-deactivate");
+        return $? ? [500, "Failed"] : [200];
+    }
+
+    [412, "Unknown screensaver '$screensaver'"];
+}
+
 # XXX get_screensaver_active_time (in KDE, we can use GetActiveTime, in xscreensaver -time, in gnome/cinnamon -t)
 # XXX get_screensaver_idle_time (in KDE, we can use GetSessionIdleTime, in xscreensaver -time, in gnome/cinnamon -t)
-# XXX hearbeat_screensaver (in KDE, we use SimulateUserActivity, in xscreensaver -deactivate?)
-# XXX run a command with screensaver disabled
 
 1;
 # ABSTRACT: Common interface to screensaver/screenlocker functions
@@ -430,7 +481,7 @@ Screensaver::Any - Common interface to screensaver/screenlocker functions
 
 =head1 VERSION
 
-This document describes version 0.001 of Screensaver::Any (from Perl distribution Screensaver-Any), released on 2017-03-30.
+This document describes version 0.002 of Screensaver::Any (from Perl distribution Screensaver-Any), released on 2017-03-31.
 
 =head1 DESCRIPTION
 
@@ -487,8 +538,13 @@ Usage:
 Deactivate screensaver and unblank the screen.
 
 If screen is not being blank (screensaver is not activated) then nothing
-happens. Also, if screen is being locked, it will not be unlocked. User will
-need to unlock the screen herself first.
+happens. If screen is being blanked (screensaver is activated) then unblank the
+screen.
+
+Often the screen is also locked when being blanked. On some screensavers, like
+xscreensaver, deactivating won't unlock the screen and user will need to unlock
+the screen herself first. Some other screensavers, like GNOME/cinnamon, will
+happily unlock the screen automatically.
 
 This function is not exported by default, but exportable.
 
@@ -609,7 +665,7 @@ Usage:
 
  get_screensaver_timeout(%args) -> [status, msg, result, meta]
 
-Get screensaver timeout, in number of seconds.
+Get screensaver idle timeout, in number of seconds.
 
 This function is not exported by default, but exportable.
 
@@ -637,11 +693,46 @@ that contains extra information.
 Return value: Timeout value, in seconds (float)
 
 
-=head2 is_screensaver_active
+=head2 prevent_screensaver_activated
 
 Usage:
 
- is_screensaver_active(%args) -> [status, msg, result, meta]
+ prevent_screensaver_activated() -> [status, msg, result, meta]
+
+Prevent screensaver from being activated by resetting idle timer.
+
+You can use this function to prevent screensaver from being activated, if it is
+not yet being activated. This is usually done by resetting the idle counter.
+With KDE, this is called "simulating user activity". With xscreensaver, one can
+use the -deactivate on the CLI.
+
+This function will need to be run periodically and often enough (more often than
+the idle timeout period) to actually keep the screensaver from ever being
+activated.
+
+If screensaver is already activated, then nothing happens.
+
+This function is not exported by default, but exportable.
+
+No arguments.
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 screensaver_is_active
+
+Usage:
+
+ screensaver_is_active(%args) -> [status, msg, result, meta]
 
 Check if screensaver is being activated.
 
@@ -677,7 +768,7 @@ Usage:
 
  set_screensaver_timeout(%args) -> [status, msg, result, meta]
 
-Set screensaver timeout.
+Set screensaver idle timeout.
 
 Examples:
 
